﻿using System;
using System.Drawing;

using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 커스텀 타일 생성기
    /// </summary>
    public class CustomTileGenerator : IImageTileSource
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 폰트
        /// </summary>
        private readonly Font font = new Font("Arial", 10);

        /// <summary>
        /// 난수기
        /// </summary>
        private Random random = new Random();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 소스 이미지 리소스 해제 가능 여부 - CanDisposeSourceImage

        /// <summary>
        /// 소스 이미지 리소스 해제 가능 여부
        /// </summary>
        public bool CanDisposeSourceImage
        {
            get
            {
                return true;
            }
        }

        #endregion
        #region 명칭 - Name

        /// <summary>
        /// 명칭
        /// </summary>
        public string Name
        {
            get
            {
                return nameof(CustomTileGenerator);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 이미지 구하기 - GetImage(x, y, level, size)

        /// <summary>
        /// 이미지 구하기
        /// </summary>
        /// <param name="x">X 좌표</param>
        /// <param name="y">Y 좌표</param>
        /// <param name="level">레벨</param>
        /// <param name="size">크기</param>
        /// <returns>이미지</returns>
        public Image GetImage(int x, int y, int level, Size size)
        {
            Bitmap bitmap = new Bitmap(size.Width, size.Height);

            using(Graphics graphics = Graphics.FromImage(bitmap))
            {
                graphics.Clear(Color.FromArgb(128, random.Next(255), random.Next(255), random.Next(255)));

                graphics.DrawString
                (
                    string.Format("X : {0}, Y : {1}, Level : {2}", x, y, level),
                    font,
                    Brushes.Black,
                    new PointF(5, 5)
                );
            }

            return bitmap;
        }

        #endregion
    }
}